@@ -2,7 +2,7 @@ from __future__ import absolute_import, division
 
 from typing import TYPE_CHECKING
 
-from ._app import Klein, handle_errors, route, run, urlFor, url_for
+from ._app import Klein, handle_errors, route, run, subroute, urlFor, url_for
 from ._dihttp import RequestComponent, RequestURL, Response
 from ._form import Field, FieldValues, Form, RenderableForm
 from ._plating import Plating
@@ -13,6 +13,7 @@ from ._version import __version__ as _incremental_version
 if TYPE_CHECKING:
     # Inform mypy of import shenanigans.
     from .resource import _SpecialModuleObject
+
     resource = _SpecialModuleObject()
 else:
     from . import resource
@@ -20,16 +21,16 @@ else:
 __all__ = (
     "Klein",
     "Plating",
-    'Field',
-    'FieldValues',
-    'Form',
-    'RequestComponent',
-    'RequestURL',
-    'Response',
-    'RenderableForm',
-    'SessionProcurer',
-    'Authorization',
-    'Requirer',
+    "Field",
+    "FieldValues",
+    "Form",
+    "RequestComponent",
+    "RequestURL",
+    "Response",
+    "RenderableForm",
+    "SessionProcurer",
+    "Authorization",
+    "Requirer",
     "__author__",
     "__copyright__",
     "__license__",
@@ -38,6 +39,7 @@ __all__ = (
     "resource",
     "route",
     "run",
+    "subroute",
     "urlFor",
     "url_for",
 )
@@ -48,4 +50,4 @@ __version__ = _incremental_version.base()
 
 __author__ = "The Klein contributors (see AUTHORS)"
 __license__ = "MIT"
-__copyright__ = "Copyright 2016-2017 {0}".format(__author__)
+__copyright__ = "Copyright 2011-2019 {0}".format(__author__)
