@@ -1,6 +1,11 @@
 from functools import wraps
+from typing import Callable, Optional, Text, TypeVar
+
+C = TypeVar("C", bound=Callable)
+
 
 def bindable(bindable):
+    # type: (C) -> C
     """
     Mark a method as a "bindable" method.
 
@@ -19,11 +24,16 @@ def bindable(bindable):
     @return: its argument, modified to mark it as unconditinally requiring an
         instance argument.
     """
-    bindable.__klein_bound__ = True
+    bindable.__klein_bound__ = True  # type: ignore[attr-defined]
     return bindable
 
 
-def modified(modification, original, modifier=None):
+def modified(
+    modification,  # type: Text
+    original,  # type: Callable
+    modifier=None,  # type: Optional[Callable]
+):
+    # type: (...) -> Callable
     """
     Annotate a callable as a modified wrapper of an original callable.
 
@@ -42,10 +52,13 @@ def modified(modification, original, modifier=None):
         return value, and is only related to C{original} in the sense that it
         likely calls it.
     """
+
     def decorator(wrapper):
-        result = (named(modification + ' for ' + original.__name__)
-                  (wraps(original)(wrapper)))
-        result.__original__ = original
+        # type: (Callable[..., C]) -> Callable[..., C]
+        result = named(modification + " for " + original.__name__)(
+            wraps(original)(wrapper)
+        )
+        result.__original__ = original  # type: ignore[attr-defined]
         if modifier is not None:
             before = set(wrapper.__dict__.keys())
             result = modifier(result)
@@ -53,26 +66,32 @@ def modified(modification, original, modifier=None):
             for key in after - before:
                 setattr(original, key, wrapper.__dict__[key])
         return result
+
     return decorator
 
 
 def named(name):
+    # type: (Text) -> Callable[[C], C]
     """
     Change the name of a function to the given name.
     """
+
     def decorator(original):
+        # type: (C) -> C
         original.__name__ = str(name)
         original.__qualname__ = str(name)
         return original
+
     return decorator
 
 
 def originalName(function):
+    # type: (Callable) -> Text
     """
     Get the original, user-specified name of C{function}, chasing back any
     wrappers applied with C{modified}.
     """
-    fnext = function
+    fnext = function  # type: Optional[Callable]
     while fnext is not None:
         function = fnext
         fnext = getattr(function, "__original__", None)
