@@ -1,7 +1,6 @@
-
 from ._memory import MemorySessionStore, declareMemoryAuthorizer
 
 __all__ = [
-    'declareMemoryAuthorizer',
-    'MemorySessionStore',
+    "declareMemoryAuthorizer",
+    "MemorySessionStore",
 ]
