@@ -28,17 +28,27 @@ from .util import EqualityTestsMixin
 from .. import Klein
 from .._interfaces import IKleinRequest
 from .._resource import (
-    KleinResource, _URLDecodeError, _extractURLparts, ensure_utf8_bytes
+    KleinResource,
+    _URLDecodeError,
+    _extractURLparts,
+    ensure_utf8_bytes,
 )
 
 
-def requestMock(path, method=b"GET", host=b"localhost", port=8080,
-                isSecure=False, body=None, headers=None):
+def requestMock(
+    path,
+    method=b"GET",
+    host=b"localhost",
+    port=8080,
+    isSecure=False,
+    body=None,
+    headers=None,
+):
     if not headers:
         headers = {}
 
     if not body:
-        body = b''
+        body = b""
 
     path, qpath = (path.split(b"?", 1) + [b""])[:2]
 
@@ -53,9 +63,9 @@ def requestMock(path, method=b"GET", host=b"localhost", port=8080,
     request.setHost(host, port, isSecure)
     request.uri = path
     request.prepath = []
-    request.postpath = path.split(b'/')[1:]
+    request.postpath = path.split(b"/")[1:]
     request.method = method
-    request.clientproto = b'HTTP/1.1'
+    request.clientproto = b"HTTP/1.1"
 
     request.setHeader = Mock(wraps=request.setHeader)
     request.setResponseCode = Mock(wraps=request.setResponseCode)
@@ -77,7 +87,7 @@ def requestMock(path, method=b"GET", host=b"localhost", port=8080,
         request.finishCount += 1
 
         if not request.startedWriting:
-            request.write(b'')
+            request.write(b"")
 
         if not request.finished:
             request.finished = True
@@ -90,8 +100,10 @@ def requestMock(path, method=b"GET", host=b"localhost", port=8080,
         if not request.finished:
             request._written.write(data)
         else:
-            raise RuntimeError('Request.write called on a request after '
-                               'Request.finish was called.')
+            raise RuntimeError(
+                "Request.write called on a request after "
+                "Request.finish was called."
+            )
 
     def getWrittenData():
         return request._written.getvalue()
@@ -137,6 +149,7 @@ class SimpleElement(Element):
     def name(self, request, tag):
         return tag(self._name)
 
+
 class DeferredElement(SimpleElement):
     @renderer
     def name(self, request, tag):
@@ -144,6 +157,7 @@ class DeferredElement(SimpleElement):
         self.deferred.addCallback(lambda ignored: tag(self._name))
         return self.deferred
 
+
 class LeafResource(Resource):
     isLeaf = True
 
@@ -166,7 +180,7 @@ class ChildrenResource(Resource):
         return b"I have children!"
 
     def getChild(self, path, request):
-        if path == b'':
+        if path == b"":
             return self
 
         return ChildResource(path)
@@ -199,11 +213,11 @@ class MockProducer(object):
             self.request.finish()
 
 
-
 class KleinResourceEqualityTests(SynchronousTestCase, EqualityTestsMixin):
     """
     Tests for L{KleinResource}'s implementation of C{==} and C{!=}.
     """
+
     class _One(object):
         oneKlein = Klein()
 
@@ -213,7 +227,6 @@ class KleinResourceEqualityTests(SynchronousTestCase, EqualityTestsMixin):
 
     _one = _One()
 
-
     class _Another(object):
         anotherKlein = Klein()
 
@@ -223,42 +236,37 @@ class KleinResourceEqualityTests(SynchronousTestCase, EqualityTestsMixin):
 
     _another = _Another()
 
-
     def anInstance(self):
         return self._one.oneKlein
 
-
     def anotherInstance(self):
         return self._another.anotherKlein
 
 
-
 class KleinResourceTests(SynchronousTestCase):
     def setUp(self):
         self.app = Klein()
         self.kr = KleinResource(self.app)
 
-
     def assertFired(self, deferred, result=None):
         """
         Assert that the given deferred has fired with the given result.
         """
         self.assertEqual(self.successResultOf(deferred), result)
 
-
     def assertNotFired(self, deferred):
         """
         Assert that the given deferred has not fired with a result.
         """
         _pawn = object()
-        result = getattr(deferred, 'result', _pawn)
+        result = getattr(deferred, "result", _pawn)
         if result != _pawn:
             self.fail(
-                "Expected deferred not to have fired, but it has: {!r}"
-                .format(deferred)
+                "Expected deferred not to have fired, but it has: {!r}".format(
+                    deferred
+                )
             )
 
-
     def test_simplePost(self):
         app = self.app
 
@@ -269,103 +277,98 @@ class KleinResourceTests(SynchronousTestCase):
 
         @app.route("/", methods=["POST"])
         def handle_post(request):
-            return b'posted'
+            return b"posted"
 
         @app.route("/")
         def handle(request):
-            return b'gotted'
+            return b"gotted"
 
-        request = requestMock(b'/', b'POST')
-        request2 = requestMock(b'/')
+        request = requestMock(b"/", b"POST")
+        request2 = requestMock(b"/")
 
         d = _render(self.kr, request)
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'posted')
+        self.assertEqual(request.getWrittenData(), b"posted")
 
         d2 = _render(self.kr, request2)
         self.assertFired(d2)
-        self.assertEqual(request2.getWrittenData(), b'gotted')
-
+        self.assertEqual(request2.getWrittenData(), b"gotted")
 
     def test_simpleRouting(self):
         app = self.app
 
         @app.route("/")
         def slash(request):
-            return b'ok'
+            return b"ok"
 
-        request = requestMock(b'/')
+        request = requestMock(b"/")
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'ok')
-
+        self.assertEqual(request.getWrittenData(), b"ok")
 
     def test_branchRendering(self):
         app = self.app
 
         @app.route("/", branch=True)
         def slash(request):
-            return b'ok'
+            return b"ok"
 
-        request = requestMock(b'/foo')
+        request = requestMock(b"/foo")
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'ok')
-
+        self.assertEqual(request.getWrittenData(), b"ok")
 
     def test_branchWithExplicitChildrenRouting(self):
         app = self.app
 
         @app.route("/")
         def slash(request):
-            return b'ok'
+            return b"ok"
 
         @app.route("/zeus")
         def wooo(request):
-            return b'zeus'
+            return b"zeus"
 
-        request = requestMock(b'/zeus')
-        request2 = requestMock(b'/')
+        request = requestMock(b"/zeus")
+        request2 = requestMock(b"/")
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'zeus')
+        self.assertEqual(request.getWrittenData(), b"zeus")
 
         d2 = _render(self.kr, request2)
 
         self.assertFired(d2)
-        self.assertEqual(request2.getWrittenData(), b'ok')
-
+        self.assertEqual(request2.getWrittenData(), b"ok")
 
     def test_branchWithExplicitChildBranch(self):
         app = self.app
 
         @app.route("/", branch=True)
         def slash(request):
-            return b'ok'
+            return b"ok"
 
         @app.route("/zeus/", branch=True)
         def wooo(request):
-            return b'zeus'
+            return b"zeus"
 
-        request = requestMock(b'/zeus/foo')
-        request2 = requestMock(b'/')
+        request = requestMock(b"/zeus/foo")
+        request2 = requestMock(b"/")
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'zeus')
+        self.assertEqual(request.getWrittenData(), b"zeus")
 
         d2 = _render(self.kr, request2)
 
         self.assertFired(d2)
-        self.assertEqual(request2.getWrittenData(), b'ok')
-
+        self.assertEqual(request2.getWrittenData(), b"ok")
 
     def test_deferredRendering(self):
         app = self.app
@@ -382,11 +385,10 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertNotFired(d)
 
-        deferredResponse.callback(b'ok')
+        deferredResponse.callback(b"ok")
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'ok')
-
+        self.assertEqual(request.getWrittenData(), b"ok")
 
     def test_elementRendering(self):
         app = self.app
@@ -400,9 +402,9 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(),
-                         b"<!DOCTYPE html>\n<h1>foo</h1>")
-
+        self.assertEqual(
+            request.getWrittenData(), b"<!DOCTYPE html>\n<h1>foo</h1>"
+        )
 
     def test_deferredElementRendering(self):
         app = self.app
@@ -423,9 +425,9 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertNoResult(d)
         oneElement.deferred.callback(None)
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(),
-                         b"<!DOCTYPE html>\n<h1>bar</h1>")
-
+        self.assertEqual(
+            request.getWrittenData(), b"<!DOCTYPE html>\n<h1>bar</h1>"
+        )
 
     def test_leafResourceRendering(self):
         app = self.app
@@ -441,7 +443,6 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertFired(d)
         self.assertEqual(request.getWrittenData(), b"I am a leaf in the wind.")
 
-
     def test_childResourceRendering(self):
         app = self.app
         request = requestMock(b"/resource/children/betty")
@@ -453,10 +454,7 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(
-            request.getWrittenData(), b"I'm a child named betty!"
-        )
-
+        self.assertEqual(request.getWrittenData(), b"I'm a child named betty!")
 
     def test_childrenResourceRendering(self):
         app = self.app
@@ -472,7 +470,6 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertFired(d)
         self.assertEqual(request.getWrittenData(), b"I have children!")
 
-
     def test_producerResourceRendering(self):
         """
         Test that Klein will correctly handle producing L{Resource}s.
@@ -492,8 +489,9 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request, notifyFinish=False)
 
         self.assertNotEqual(
-            request.getWrittenData(), b"abcd",
-            "The full response should not have been written at this point."
+            request.getWrittenData(),
+            b"abcd",
+            "The full response should not have been written at this point.",
         )
 
         while request.producer:
@@ -505,7 +503,6 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertEqual(request.finishCount, 1)
         self.assertEqual(request.producer, None)
 
-
     def test_notFound(self):
         request = requestMock(b"/fourohofour")
 
@@ -515,7 +512,6 @@ class KleinResourceTests(SynchronousTestCase):
         request.setResponseCode.assert_called_with(404)
         self.assertIn(b"404 Not Found", request.getWrittenData())
 
-
     def test_renderUnicode(self):
         app = self.app
 
@@ -523,14 +519,13 @@ class KleinResourceTests(SynchronousTestCase):
 
         @app.route("/snowman")
         def snowman(request):
-            return u'\u2603'
+            return u"\u2603"
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
         self.assertEqual(request.getWrittenData(), b"\xE2\x98\x83")
 
-
     def test_renderNone(self):
         app = self.app
 
@@ -543,17 +538,16 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'')
+        self.assertEqual(request.getWrittenData(), b"")
         self.assertEqual(request.finishCount, 1)
         self.assertEqual(request.writeCount, 1)
 
-
     def test_staticRoot(self):
         app = self.app
 
         request = requestMock(b"/__init__.py")
         expected = open(
-            os.path.join(os.path.dirname(__file__), "__init__.py"), 'rb'
+            os.path.join(os.path.dirname(__file__), "__init__.py"), "rb"
         ).read()
 
         @app.route("/", branch=True)
@@ -566,13 +560,12 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertEqual(request.getWrittenData(), expected)
         self.assertEqual(request.finishCount, 1)
 
-
     def test_explicitStaticBranch(self):
         app = self.app
 
         request = requestMock(b"/static/__init__.py")
         expected = open(
-            os.path.join(os.path.dirname(__file__), "__init__.py"), 'rb'
+            os.path.join(os.path.dirname(__file__), "__init__.py"), "rb"
         ).read()
 
         @app.route("/static/", branch=True)
@@ -598,7 +591,7 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertIn(b'Directory listing', request.getWrittenData())
+        self.assertIn(b"Directory listing", request.getWrittenData())
         self.assertEqual(request.writeCount, 1)
         self.assertEqual(request.finishCount, 1)
 
@@ -614,17 +607,19 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertFired(d)
         self.assertEqual(request.setHeader.call_count, 3)
-        request.setHeader.assert_has_calls([
-            call(b'Content-Type', b'text/html; charset=utf-8'),
-            call(b'Content-Length', b'259'),
-            call(b'Location', b'http://localhost:8080/foo/')
-        ])
+        request.setHeader.assert_has_calls(
+            [
+                call(b"Content-Type", b"text/html; charset=utf-8"),
+                call(b"Content-Length", b"259"),
+                call(b"Location", b"http://localhost:8080/foo/"),
+            ]
+        )
 
     def test_methodNotAllowed(self):
         app = self.app
-        request = requestMock(b"/foo", method=b'DELETE')
+        request = requestMock(b"/foo", method=b"DELETE")
 
-        @app.route("/foo", methods=['GET'])
+        @app.route("/foo", methods=["GET"])
         def foo(request):
             return "foo"
 
@@ -635,13 +630,13 @@ class KleinResourceTests(SynchronousTestCase):
 
     def test_methodNotAllowedWithRootCollection(self):
         app = self.app
-        request = requestMock(b"/foo/bar", method=b'DELETE')
+        request = requestMock(b"/foo/bar", method=b"DELETE")
 
-        @app.route("/foo/bar", methods=['GET'])
+        @app.route("/foo/bar", methods=["GET"])
         def foobar(request):
             return b"foo/bar"
 
-        @app.route("/foo/", methods=['DELETE'])
+        @app.route("/foo/", methods=["DELETE"])
         def foo(request):
             return b"foo"
 
@@ -678,30 +673,30 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertFired(d)
         self.assertEqual(str(request_url[0]), "http://localhost:8080/foo/bar")
-        self.assertEqual(request.getWrittenData(), b'foo')
+        self.assertEqual(request.getWrittenData(), b"foo")
         self.assertEqual(request.code, 200)
 
     def test_URLPath(self):
         app = self.app
-        request = requestMock(b'/egg/chicken')
+        request = requestMock(b"/egg/chicken")
 
         request_url = [None]
 
         @app.route("/egg/chicken")
         def wooo(request):
             request_url[0] = request.URLPath()
-            return b'foo'
+            return b"foo"
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
         self.assertEqual(
-            str(request_url[0]), 'http://localhost:8080/egg/chicken'
+            str(request_url[0]), "http://localhost:8080/egg/chicken"
         )
 
     def test_URLPath_root(self):
         app = self.app
-        request = requestMock(b'/')
+        request = requestMock(b"/")
 
         request_url = [None]
 
@@ -712,11 +707,11 @@ class KleinResourceTests(SynchronousTestCase):
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(str(request_url[0]), 'http://localhost:8080/')
+        self.assertEqual(str(request_url[0]), "http://localhost:8080/")
 
     def test_URLPath_traversedResource(self):
         app = self.app
-        request = requestMock(b'/resource/foo')
+        request = requestMock(b"/resource/foo")
 
         request_url = [None]
 
@@ -735,7 +730,7 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertFired(d)
         self.assertEqual(
-            str(request_url[0]), 'http://localhost:8080/resource/foo'
+            str(request_url[0]), "http://localhost:8080/resource/foo"
         )
 
     def test_handlerRaises(self):
@@ -837,7 +832,7 @@ class KleinResourceTests(SynchronousTestCase):
         @app.handle_errors(NotFound)
         def handle_not_found(request, failure):
             request.setResponseCode(404)
-            return b'Custom Not Found'
+            return b"Custom Not Found"
 
         @app.handle_errors
         def handle_generic_error(request, failure):
@@ -851,7 +846,7 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertEqual(request.processingFailed.called, False)
         self.assertEqual(generic_error_handled, False)
         self.assertEqual(request.code, 404)
-        self.assertEqual(request.getWrittenData(), b'Custom Not Found')
+        self.assertEqual(request.getWrittenData(), b"Custom Not Found")
         self.assertEqual(request.writeCount, 1)
 
     def test_errorHandlerNeedsRendering(self):
@@ -885,7 +880,7 @@ class KleinResourceTests(SynchronousTestCase):
 
             def render(self, request):
                 request.setResponseCode(404)
-                return b'Nothing found'
+                return b"Nothing found"
 
         @app.handle_errors(NotFound)
         def handle_not_found(request, failure):
@@ -895,7 +890,7 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertFired(d)
         self.assertEqual(request.code, 404)
-        self.assertEqual(request.getWrittenData(), b'Nothing found')
+        self.assertEqual(request.getWrittenData(), b"Nothing found")
 
     def test_requestWriteAfterFinish(self):
         app = self.app
@@ -904,19 +899,22 @@ class KleinResourceTests(SynchronousTestCase):
         @app.route("/")
         def root(request):
             request.finish()
-            return b'foo'
+            return b"foo"
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
         self.assertEqual(request.writeCount, 2)
-        self.assertEqual(request.getWrittenData(), b'')
+        self.assertEqual(request.getWrittenData(), b"")
         [failure] = self.flushLoggedErrors(RuntimeError)
 
         self.assertEqual(
             str(failure.value),
-            ("Request.write called on a request after Request.finish was "
-             "called."))
+            (
+                "Request.write called on a request after Request.finish was "
+                "called."
+            ),
+        )
 
     def test_requestFinishAfterConnectionLost(self):
         app = self.app
@@ -926,7 +924,7 @@ class KleinResourceTests(SynchronousTestCase):
 
         @app.route("/")
         def root(request):
-            request.notifyFinish().addBoth(lambda _: finished.callback(b'foo'))
+            request.notifyFinish().addBoth(lambda _: finished.callback(b"foo"))
             return finished
 
         d = _render(self.kr, request)
@@ -936,8 +934,11 @@ class KleinResourceTests(SynchronousTestCase):
 
             self.assertEqual(
                 str(failure.value),
-                ("Request.finish called on a request after its connection was "
-                 "lost; use Request.notifyFinish to keep track of this."))
+                (
+                    "Request.finish called on a request after its connection "
+                    "was lost; use Request.notifyFinish to keep track of this."
+                ),
+            )
 
         d.addErrback(lambda _: finished)
         d.addErrback(_eb)
@@ -948,7 +949,6 @@ class KleinResourceTests(SynchronousTestCase):
 
         self.assertFired(d)
 
-
     def test_routeHandlesRequestFinished(self):
         app = self.app
         request = requestMock(b"/")
@@ -969,25 +969,25 @@ class KleinResourceTests(SynchronousTestCase):
         self.assertFired(d)
 
         cancelled[0].trap(CancelledError)
-        self.assertEqual(request.getWrittenData(), b'')
+        self.assertEqual(request.getWrittenData(), b"")
         self.assertEqual(request.writeCount, 1)
         self.assertEqual(request.processingFailed.call_count, 0)
 
     def test_url_for(self):
         app = self.app
-        request = requestMock(b'/foo/1')
+        request = requestMock(b"/foo/1")
 
         relative_url = [None]
 
         @app.route("/foo/<int:bar>")
         def foo(request, bar):
             krequest = IKleinRequest(request)
-            relative_url[0] = krequest.url_for('foo', {'bar': bar + 1})
+            relative_url[0] = krequest.url_for("foo", {"bar": bar + 1})
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(relative_url[0], '/foo/2')
+        self.assertEqual(relative_url[0], "/foo/2")
 
     def test_cancelledDeferred(self):
         app = self.app
@@ -1008,7 +1008,7 @@ class KleinResourceTests(SynchronousTestCase):
 
     def test_external_url_for(self):
         app = self.app
-        request = requestMock(b'/foo/1')
+        request = requestMock(b"/foo/1")
 
         relative_url = [None]
 
@@ -1016,13 +1016,13 @@ class KleinResourceTests(SynchronousTestCase):
         def foo(request, bar):
             krequest = IKleinRequest(request)
             relative_url[0] = krequest.url_for(
-                'foo', {'bar': bar + 1}, force_external=True
+                "foo", {"bar": bar + 1}, force_external=True
             )
 
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(relative_url[0], 'http://localhost:8080/foo/2')
+        self.assertEqual(relative_url[0], "http://localhost:8080/foo/2")
 
     def test_cancelledIsEatenOnConnectionLost(self):
         app = self.app
@@ -1121,41 +1121,40 @@ class KleinResourceTests(SynchronousTestCase):
     else:
         test_urlDecodeErrorReprPy3.skip = "Only works on Py3"  # type: ignore
 
-
     def test_subroutedBranch(self):
         subapp = Klein()
 
-        @subapp.route('/foo')
+        @subapp.route("/foo")
         def foo(request):
-            return b'foo'
+            return b"foo"
 
         app = self.app
-        with app.subroute('/sub') as app:
-            @app.route('/app', branch=True)
+        with app.subroute("/sub") as app:
+
+            @app.route("/app", branch=True)
             def subapp_endpoint(request):
                 return subapp.resource()
 
-        request = requestMock(b'/sub/app/foo')
+        request = requestMock(b"/sub/app/foo")
         d = _render(self.kr, request)
 
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'foo')
-
+        self.assertEqual(request.getWrittenData(), b"foo")
 
     def test_correctContentLengthForRequestRedirect(self):
         app = self.app
 
-        @app.route('/alias', alias=True)
-        @app.route('/real')
+        @app.route("/alias", alias=True)
+        @app.route("/real")
         def real(req):
-            return b'42'
+            return b"42"
 
-        request = requestMock(b'/real')
+        request = requestMock(b"/real")
         d = _render(self.kr, request)
         self.assertFired(d)
-        self.assertEqual(request.getWrittenData(), b'42')
+        self.assertEqual(request.getWrittenData(), b"42")
 
-        request = requestMock(b'/alias')
+        request = requestMock(b"/alias")
         d = _render(self.kr, request)
         self.assertFired(d)
         # Werkzeug switched the redirect status code used from 301 to 308.
@@ -1164,7 +1163,7 @@ class KleinResourceTests(SynchronousTestCase):
 
         actual_length = len(request.getWrittenData())
         reported_length = int(
-            request.responseHeaders.getRawHeaders(b'content-length')[0]
+            request.responseHeaders.getRawHeaders(b"content-length")[0]
         )
         self.assertEqual(reported_length, actual_length)
 
@@ -1173,13 +1172,18 @@ class ExtractURLpartsTests(SynchronousTestCase):
     """
     Tests for L{klein.resource._extractURLparts}.
     """
+
     def test_types(self):
         """
         Returns the correct types.
         """
-        url_scheme, server_name, server_port, path_info, script_name = (
-            _extractURLparts(requestMock(b"/f\xc3\xb6\xc3\xb6"))
-        )
+        (
+            url_scheme,
+            server_name,
+            server_port,
+            path_info,
+            script_name,
+        ) = _extractURLparts(requestMock(b"/f\xc3\xb6\xc3\xb6"))
 
         self.assertIsInstance(url_scheme, unicode)
         self.assertIsInstance(server_name, unicode)
@@ -1187,7 +1191,6 @@ class ExtractURLpartsTests(SynchronousTestCase):
         self.assertIsInstance(path_info, unicode)
         self.assertIsInstance(script_name, unicode)
 
-
     def assertDecodingFailure(self, exception, part):
         """
         Checks whether C{exception} consists of a single L{UnicodeDecodeError}
@@ -1198,7 +1201,6 @@ class ExtractURLpartsTests(SynchronousTestCase):
         self.assertEqual(part, actualPart)
         self.assertIsInstance(actualFail.value, UnicodeDecodeError)
 
-
     def test_failServerName(self):
         """
         Raises URLDecodeError if SERVER_NAME can't be decoded.
@@ -1208,7 +1210,6 @@ class ExtractURLpartsTests(SynchronousTestCase):
         e = self.assertRaises(_URLDecodeError, _extractURLparts, request)
         self.assertDecodingFailure(e, "SERVER_NAME")
 
-
     def test_failPathInfo(self):
         """
         Raises URLDecodeError if PATH_INFO can't be decoded.
@@ -1217,7 +1218,6 @@ class ExtractURLpartsTests(SynchronousTestCase):
         e = self.assertRaises(_URLDecodeError, _extractURLparts, request)
         self.assertDecodingFailure(e, "PATH_INFO")
 
-
     def test_failScriptName(self):
         """
         Raises URLDecodeError if SCRIPT_NAME can't be decoded.
@@ -1227,7 +1227,6 @@ class ExtractURLpartsTests(SynchronousTestCase):
         e = self.assertRaises(_URLDecodeError, _extractURLparts, request)
         self.assertDecodingFailure(e, "SCRIPT_NAME")
 
-
     def test_failAll(self):
         """
         If multiple parts fail, they all get appended to the errors list of
@@ -1239,7 +1238,7 @@ class ExtractURLpartsTests(SynchronousTestCase):
         e = self.assertRaises(_URLDecodeError, _extractURLparts, request)
         self.assertEqual(
             set(["SERVER_NAME", "PATH_INFO", "SCRIPT_NAME"]),
-            set(part for part, _ in e.errors)
+            set(part for part, _ in e.errors),
         )
 
     def test_afUnixSocket(self):
@@ -1248,10 +1247,14 @@ class ExtractURLpartsTests(SynchronousTestCase):
         """
         request = requestMock(b"/f\xc3\xb6\xc3\xb6")
         server_mock = Mock(Server)
-        server_mock.getRequestHostname = u'/var/run/twisted.socket'
+        server_mock.getRequestHostname = u"/var/run/twisted.socket"
         request.host = server_mock
         (
-            url_scheme, server_name, server_port, path_info, script_name
+            url_scheme,
+            server_name,
+            server_port,
+            path_info,
+            script_name,
         ) = _extractURLparts(request)
 
         self.assertIsInstance(url_scheme, unicode)
@@ -1275,19 +1278,18 @@ class GlobalAppTests(SynchronousTestCase):
         self.assertIs(resource.__self__, globalApp)
         self.assertIs(handle_errors.__self__, globalApp)
 
-        @route('/')
+        @route("/")
         def index(request):
             1 // 0
 
         @handle_errors(ZeroDivisionError)
         def on_zero(request, failure):
-            return b'alive'
+            return b"alive"
 
-        request = requestMock(b'/')
+        request = requestMock(b"/")
         d = _render(resource(), request)
         self.assertIsNone(self.successResultOf(d))
-        self.assertEqual(request.getWrittenData(), b'alive')
-
+        self.assertEqual(request.getWrittenData(), b"alive")
 
     def test_weird_resource_situation(self):
         """
@@ -1309,14 +1311,18 @@ class GlobalAppTests(SynchronousTestCase):
         """
         from klein import resource
         from klein.resource import KleinResource, ensure_utf8_bytes
-        self.assertEqual(repr(resource),
-                         "<special bound method/module klein.resource>")
+
+        self.assertEqual(
+            repr(resource), "<special bound method/module klein.resource>"
+        )
         self.assertIdentical(resource.KleinResource, KleinResource)
         self.assertIdentical(resource.ensure_utf8_bytes, ensure_utf8_bytes)
 
 
 if _PY3:
     import sys
+
     if sys.version_info >= (3, 5):
         from .py3_test_resource import PY3KleinResourceTests
+
         PY3KleinResourceTests  # shh pyflakes
